@@ -3,7 +3,7 @@ use warnings;
 
 package Perl::PrereqScanner::Scanner::Moose;
 BEGIN {
-  $Perl::PrereqScanner::Scanner::Moose::VERSION = '1.002';
+  $Perl::PrereqScanner::Scanner::Moose::VERSION = '1.003';
 }
 use Moose;
 with 'Perl::PrereqScanner::Scanner';
@@ -27,7 +27,7 @@ sub scan_for_prereqs {
     #   PPI::Token::Structure
 
     map  { [ $_->children ] }
-    grep { $_->child(0)->literal =~ m{\Awith|extends\z} }
+    grep { $_->child(0)->literal =~ m{\A(?:with|extends)\z} }
     grep { $_->child(0)->isa('PPI::Token::Word') }
     @{ $ppi_doc->find('PPI::Statement') || [] };
 
@@ -122,7 +122,7 @@ Perl::PrereqScanner::Scanner::Moose - scan for Moose sugar indicators of require
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 DESCRIPTION
 
@@ -142,8 +142,17 @@ L<Moose> roles included with the C<with> keyword
 
 =head1 AUTHORS
 
-  Jerome Quelin
-  Ricardo Signes <rjbs@cpan.org>
+=over 4
+
+=item *
+
+Jerome Quelin
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
